// <copyright file="CTRMode.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> CTRMode
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2.Crypto.Cipher
{
    /// <summary>
    /// Class used for CTRMode ecryption.
    /// </summary>
    public class CTRMode : IBlockCipher
    {
        private byte[] x;
        private byte[] xenc;

        private IBlockCipher bc;
        private int blockSize;

        // private int count = 0;

        /// <summary>
        /// Initializes a new instance of the CTRMode class.
        /// </summary>
        /// <param name="blockCipher">The underlying cipher to use.</param>
        /// <param name="iv">The IV to use.</param>
        public CTRMode(IBlockCipher blockCipher, byte[] iv)
        {
            this.bc = blockCipher;
            this.blockSize = this.bc.BlockSize;

            if (this.blockSize != iv.Length)
            {
                throw new ArgumentException("IV must be " + this.blockSize + " bytes long! (currently " + iv.Length + ")");
            }

            this.x = new byte[this.blockSize];
            this.xenc = new byte[this.blockSize];

            Array.Copy(iv, 0, this.x, 0, this.blockSize);
        }

        /// <summary>
        /// Gets the Block Size.
        /// </summary>
        /// <returns>The block size of the underlying cipher.</returns>
        public int BlockSize
        {
            get { return this.blockSize; }
        }

        /// <summary>
        /// Initializes the CTRMode cipher.  For CBC and CTR this does nothing.
        /// </summary>
        /// <param name="forEncryption">True for encryption, false for decryption.</param>
        /// <param name="key">The key that we want to use. </param>
        public void Init(bool forEncryption, byte[] key)
        {
        }

        /// <summary>
        /// Transforms a block of byte data and encrypts, or decrypts it depending on
        /// how the CTRMode instance was created.
        /// </summary>
        /// <param name="source">Byte array of data to be processed.</param>
        /// <param name="sourceOffset">Offset of where we begin processing, (normally 0).</param>
        /// <param name="destination">Resulting byte array after encrypting/decrypting.</param>
        /// <param name="destinationOffset">Offset to where the processed data is placed, (normally 0).</param>
        public void TransformBlock(byte[] source, int sourceOffset, byte[] destination, int destinationOffset)
        {
            this.bc.TransformBlock(this.x, 0, this.xenc, 0);

            for (int i = 0; i < this.blockSize; i++)
            {
                unchecked
                {
                    destination[destinationOffset + i] = (byte)(source[sourceOffset + i] ^ this.xenc[i]);
                }
            }

            for (int i = this.blockSize - 1; i >= 0; i--)
            {
                unchecked
                {
                    this.x[i]++;
                }

                if (this.x[i] != 0)
                {
                    break;
                }
            }
        }
    }
}
