﻿// <copyright file="IBlockCipher.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> IBlockCipher
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

namespace Eunomia.SSH2.Crypto.Cipher
{
    /// <summary>
    /// Interface that all the block encryption classes inherit from.
    /// </summary>
    public interface IBlockCipher
    {
        /// <summary>
        /// Gets the blocksize.
        /// </summary>
        int BlockSize
        {
            get;
        }
        
        /// <summary>
        /// You must call this (for AES, DES, Blowfish and DESede at least) before actually encrypting
        /// or decrypting data via calls to TransformBlock.
        /// </summary>
        /// <param name="forEncryption"> True for encryption, false for decryption. </param>
        /// <param name="key"> The key that we want to use. </param>
        void Init(bool forEncryption, byte[] key);

        /// <summary>
        /// Transforms a block of byte data and encrypts, or decrypts it depending on
        /// how the Init method was called.
        /// </summary>
        /// <param name="source"> Byte array of data to be processed. </param>
        /// <param name="sourceOffset"> Offset of where we begin processing, (normally 0). </param>
        /// <param name="destination"> Resulting byte array after encrypting/decrypting. </param>
        /// <param name="destinationOffset"> Offset to where the processed data is placed, (normally 0). </param>
        void TransformBlock(byte[] source, int sourceOffset, byte[] destination, int destinationOffset);
    }
}
