// <copyright file="NullCipher.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> NullCipher
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2.Crypto.Cipher
{
    /// <summary>
    /// Class used for Nullcipher ecryption.
    /// </summary>
    /// <example>
    /// Nullcipher ns = new Nullcipher();
    /// </example>
    public class NullCipher : IBlockCipher
    {
        /// <summary>
        /// AlgorithmName is always "Null".
        /// </summary>
        public const string AlgorithmName = "Null";
        private int blockSize = 8;

        /// <summary>
        /// Initializes a new instance of the NullCipher class.
        /// </summary>
        public NullCipher()
        {
        }

        /// <summary> Gets the Block Size. </summary>
        /// <returns> 8 bytes for NullCipher. </returns>
        public int BlockSize
        {
            get { return this.blockSize; }
        }

        /// <summary>
        /// Initializes the NullCipher.  Don't tell anyone...this does nothing.
        /// </summary>
        /// <param name="forEncryption"> True for encryption, false for decryption.</param>
        /// <param name="key"> The key that we want to use.</param>
        public void Init(bool forEncryption, byte[] key)
        {
        }

        /// <summary>
        /// Transforms a block of byte data and encrypts, or decrypts it depending on how the
        /// Init method was called.  Er...well...for NullCipher it does nothing but copy the data.
        /// </summary>
        /// <param name="source"> Byte array of data to be processed. </param>
        /// <param name="sourceOffset"> Offset of where we begin processing, (normally 0). </param>
        /// <param name="destination"> Resulting byte array after encrypting/decrypting. </param>
        /// <param name="destinationOffset"> Offset to where the processed data is placed, (normally 0). </param>
        public void TransformBlock(byte[] source, int sourceOffset, byte[] destination, int destinationOffset)
        {
            Array.Copy(source, sourceOffset, destination, destinationOffset, this.blockSize);
        }
    }
}
