﻿// <copyright file="HTTPProxyException.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> HTTPProxyException
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;
using System.IO;

namespace Eunomia.SSH2
{
    /// <summary>
    /// May be thrown upon Connect() if a HTTP proxy is being used.
    /// </summary>
    /// <seealso cref="Connection.Connect()"></seealso>
    /// <seealso cref="Connection.ProxyData"></seealso>
    //// TODO: Implement the other required methods.
    [Serializable]
    [SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors",
                    Justification = "TODO: Implement the other required methods.")]
    public class HttpProxyException : IOException
    {
        /// <summary>
        /// Initializes a new instance of the HttpProxyException class.
        /// This class does not implement all of the usual constructors and methods that
        /// an exception should.
        /// </summary>
        /// <param name="httpResponse">The response received from the proxy.</param>
        /// <param name="httpErrorCode">The error code received from the proxy.</param>
        public HttpProxyException(string httpResponse, int httpErrorCode) : base("HTTP Proxy Error (" + httpErrorCode + " " + httpResponse + ")")
        {
        }
    }
}
