﻿// <copyright file="IServerHostKeyVerifier.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> ServerHostKeyVerifier
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2
{
    /// <summary>
    /// Interface inherited by user written classes that verify the host key.
    /// </summary>
    public interface IServerHostkeyVerifier
    {
        /// <summary>
        /// The actual verifier method, it will be called by the key exchange code
        /// on EVERY key exchange - this can happen several times during the lifetime
        /// of a connection.
        /// <para>
        /// Note: SSH-2 servers are allowed to change their hostkey at ANY time.
        /// </para>
        /// </summary>
        /// <param name="hostName">The hostName used to create the Connection object.</param>
        /// <param name="port">Tthe remote TCP port.</param>
        /// <param name="serverHostkeyAlgorithm">The public key algorithm (ssh-rsa or ssh-dss).</param>
        /// <param name="serverHostkey">The server's public key blob.</param>
        /// <returns>
        /// True if the client wants to accept the server's host key - if not, the
        /// connection will be closed.
        /// </returns>
        bool VerifyServerHostkey(string hostName, int port, string serverHostkeyAlgorithm, byte[] serverHostkey);
    }
}
