// <copyright file="LocalPortForwarder.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> LocalPortForwarder
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Net;

using Eunomia.SSH2.Channel;

namespace Eunomia.SSH2
{
    /// <summary>
    /// A <c>LocalPortForwarder</c> forwards TCP/IP connections to a local
    /// port via the secure tunnel to another host (which may or may not be identical
    /// to the remote SSH-2 server). Checkout <c>Connection.CreateLocalPortForwarder(int, string, int)</c>.
    /// </summary>
    /// <seealso cref="Connection.CreateLocalPortForwarder(int, string, int)"></seealso>
    public class LocalPortForwarder
    {
        private LocalAcceptThread lat;

        /// <summary>
        /// Initializes a new instance of the LocalPortForwarder class.
        /// </summary>
        /// <param name="cm">The ChannelManager that manages this forward.</param>
        /// <param name="localPort">The local port to forward from.</param>
        /// <param name="hostToConnect">The host to forward to.</param>
        /// <param name="portToConnect">The port to forward to.</param>
        internal LocalPortForwarder(ChannelManager cm, int localPort, string hostToConnect, int portToConnect)
        {
            this.lat = new LocalAcceptThread(cm, localPort, hostToConnect, portToConnect);
            this.lat.IsBackground = true;
            this.lat.Start();
        }
        
        /// <summary>
        /// Initializes a new instance of the LocalPortForwarder class.
        /// </summary>
        /// <param name="cm">The ChannelManager that manages this forward.</param>
        /// <param name="addr">The IPEndPoint that we forward from.</param>
        /// <param name="hostToConnect">The host to forward to.</param>
        /// <param name="portToConnect">The port to forward to.</param>
        internal LocalPortForwarder(ChannelManager cm, IPEndPoint addr, string hostToConnect, int portToConnect)
        {
            this.lat = new LocalAcceptThread(cm, addr, hostToConnect, portToConnect);
            this.lat.IsBackground = true;
            this.lat.Start();
        }

        /// <summary>
        /// Stop TCP/IP forwarding of newly arriving connections.
        /// </summary>
        /// <exception cref="System.IO.IOException"></exception>
        public void Close()
        {
            this.lat.StopWorking();
        }
    }
}
