// <copyright file="Logger.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> Logger
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2.Log
{
    /// <summary>
    /// Logger - a very simple logger, mainly used during development.
    /// Is not based on log4net (to reduce external dependencies).
    /// However, if needed, something like log4net could easily be
    /// hooked in.
    /// </summary>
    public class Logger
    {
        private const int LogLevel = 99;
        private bool enabled = false;
        private string className;

        /// <summary>
        /// Initializes a new instance of the Logger class.
        /// </summary>
        /// <param name="x">The type the logger is created for.</param>
        public Logger(Type x)
        {
            this.className = x.FullName;
        }

        /// <summary>
        /// Gets or sets a value indicating whether the Logger is enabled or not.
        /// </summary>
        public bool Enabled
        {
            get { return this.enabled; }
            set { this.enabled = value; }
        }

        /// <summary>
        /// Static method to initialize and return a Logger.
        /// </summary>
        /// <param name="x">The type the logger is created for.</param>
        /// <returns>A Logger instance.</returns>
        public static Logger GetLogger(Type x)
        {
            return new Logger(x);
        }

        /// <summary>
        /// Create a Log line (or entry). 
        /// </summary>
        /// <param name="level">The severity of the entry.</param>
        /// <param name="message">The log message.</param>
        public void Log(int level, string message)
        {
            if (this.enabled && (level <= LogLevel))
            {
                long now = System.DateTime.Now.Millisecond;

                lock (this)
                {
                    System.Console.WriteLine(now + " : " + this.className + " : " + message);

                    // or send it to log4j or whatever...
                }
            }
        }
    }
}
