﻿// <copyright file="PacketGlobalCancelForwardRequest.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketGlobalCancelForwardRequest
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketGlobalCancelForwardRequest packet.
    /// </summary>
    public class PacketGlobalCancelForwardRequest
    {
        private byte[] payload;

        private bool wantReply;
        private string bindAddress;
        private int bindPort;

        /// <summary>
        /// Initializes a new instance of the PacketGlobalCancelForwardRequest class.
        /// </summary>
        /// <param name="wantReply">Whether we want a reply.</param>
        /// <param name="bindAddress">The bind address.</param>
        /// <param name="bindPort">The bind port.</param>
        public PacketGlobalCancelForwardRequest(bool wantReply, string bindAddress, int bindPort)
        {
            this.wantReply = wantReply;
            this.bindAddress = bindAddress;
            this.bindPort = bindPort;
        }

        /// <summary>Gets or sets a value indicating whether we need a reply.</summary>
        public bool WantReply
        {
            get { return this.wantReply; }
            set { this.wantReply = value; }
        }
        
        /// <summary>Gets or sets the bind address.</summary>
        public string BindAddress
        {
            get { return this.bindAddress; }
            set { this.bindAddress = value; }
        }
        
        /// <summary>Gets or sets the bind port.</summary>
        public int BindPort
        {
            get { return this.bindPort; }
            set { this.bindPort = value; }
        }

        /// <summary>
        /// Gets the constructed payload for the packet.
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageGlobalRequest);
                    
                    tw.WriteString("cancel-tcpip-forward");
                    tw.WriteBoolean(this.wantReply);
                    tw.WriteString(this.bindAddress);
                    tw.WriteUINT32((uint)this.bindPort);
                    
                    this.payload = tw.GetBytes();
                }
                
                return this.payload;
            }
        }
    }
}
