// <copyright file="PacketKexDHInit.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketKexDHInit
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;
using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketKexDhInit packet.
    /// </summary>
    public class PacketKexDHInit
    {
        private byte[] payload;

        private BigInteger e;

        /// <summary>
        /// Initializes a new instance of the PacketKexDHInit class.
        /// This is step 1 in an older style Diffie-Hellman exchange described in RFC 4253.
        /// </summary>
        /// <param name="e">This is the 'public' key of the client.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "e", Justification = "Consistancy to ganymed project.")]
        public PacketKexDHInit(BigInteger e)
        {
            this.e = e;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageKEXDHInitialize);
                    tw.WriteMPInt(this.e);
                    this.payload = tw.GetBytes();
                }
                
                return this.payload;
            }
        }
    }
}
