// <copyright file="PacketNewKeys.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketNewKeys
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketNewKeys packet.
    /// </summary>
    public class PacketNewKeys
    {
        private byte[] payload;

        /// <summary>
        /// Initializes a new instance of the PacketNewKeys class.
        /// </summary>
        public PacketNewKeys()
        {
        }

        /// <summary>
        /// Initializes a new instance of the PacketNewKeys class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketNewKeys(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageNewKeys)
            {
                throw new IOException("This is not a SSHMessageNEWKEYS! ("
                                      + packet_type + ")");
            }
            
            if (tr.Remain != 0)
            {
                throw new IOException("Padding in SSHMessageNEWKEYS packet!");
            }
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageNewKeys);
                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
