// <copyright file="PacketSessionStartShell.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketSessionStartShell
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketSessionStartShell packet.
    /// </summary>
    public class PacketSessionStartShell
    {
        private byte[] payload;

        private int recipientChannelId;
        private bool wantReply;

        /// <summary>
        /// Initializes a new instance of the PacketSessionStartShell class.
        /// </summary>
        /// <param name="recipientChannelId">The receipient channel id.</param>
        /// <param name="wantReply">Whether a reply is wanted.</param>
        public PacketSessionStartShell(int recipientChannelId, bool wantReply)
        {
            this.recipientChannelId = recipientChannelId;
            this.wantReply = wantReply;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageChannelRequest);
                    tw.WriteUINT32((uint)this.recipientChannelId);
                    tw.WriteString("shell");
                    tw.WriteBoolean(this.wantReply);
                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
