// <copyright file="PacketSessionX11Request.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketSessionX11Request
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketSessionX11Request packet.
    /// </summary>
    public class PacketSessionX11Request
    {
        private byte[] payload;

        private int recipientChannelId;
        private bool wantReply;

        private bool singleConnection;
        private string x11AuthenticationProtocol;
        private string x11AuthenticationCookie;
        private int x11ScreenNumber;

        /// <summary>
        /// Initializes a new instance of the PacketSessionX11Request class.
        /// </summary>
        /// <param name="recipientChannelId">The receipient channel id.</param>
        /// <param name="wantReply">Whether a reply is wanted.</param>
        /// <param name="singleConnection">Whether this connection should be limited to a single connection.</param>
        /// <param name="x11AuthenticationProtocol">The X11 Authentication Protocol to use.</param>
        /// <param name="x11AuthenticationCookie">The X11 Authentication cookie.</param>
        /// <param name="x11ScreenNumber">The X11 screen number.</param>
        public PacketSessionX11Request(
            int recipientChannelId,
            bool wantReply,
            bool singleConnection,
            string x11AuthenticationProtocol,
            string x11AuthenticationCookie,
            int x11ScreenNumber)
        {
            this.recipientChannelId = recipientChannelId;
            this.wantReply = wantReply;

            this.singleConnection = singleConnection;
            this.x11AuthenticationProtocol = x11AuthenticationProtocol;
            this.x11AuthenticationCookie = x11AuthenticationCookie;
            this.x11ScreenNumber = x11ScreenNumber;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageChannelRequest);
                    tw.WriteUINT32((uint)this.recipientChannelId);
                    tw.WriteString("x11-req");
                    tw.WriteBoolean(this.wantReply);

                    tw.WriteBoolean(this.singleConnection);
                    tw.WriteString(this.x11AuthenticationProtocol);
                    tw.WriteString(this.x11AuthenticationCookie);
                    tw.WriteUINT32((uint)this.x11ScreenNumber);

                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
