// <copyright file="PacketUserauthFailure.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketUserauthFailure
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketUserauthFailure packet.
    /// </summary>
    public class PacketUserauthFailure
    {
        private byte[] payload;
        private string[] authThatCanContinue;
        private bool partialSuccess;

        /// <summary>
        /// Initializes a new instance of the PacketUserauthFailure class.
        /// </summary>
        /// <param name="authThatCanContinue">Remaining authorization methods that can continue.</param>
        /// <param name="partialSuccess">Partial success boolean.</param>
        public PacketUserauthFailure(string[] authThatCanContinue, bool partialSuccess)
        {
            this.authThatCanContinue = authThatCanContinue;
            this.partialSuccess = partialSuccess;
        }
        
        /// <summary>
        /// Initializes a new instance of the PacketUserauthFailure class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketUserauthFailure(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageUserAuthorizationFailure)
            {
                throw new IOException("This is not a SSHMessageUserAuthorizationFAILURE! (" + packet_type + ")");
            }

            this.authThatCanContinue = tr.ReadNameList();
            this.partialSuccess = tr.ReadBoolean();

            if (tr.Remain != 0)
            {
                throw new IOException("Padding in SSHMessageUserAuthorizationFAILURE packet!");
            }
        }

        /// <summary>
        /// Gets the string array of authorization methods that can continue.
        /// </summary>
        public string[] AuthThatCanContinue
        {
            get { return this.authThatCanContinue; }
        }

        /// <summary>
        /// Gets a value indicating whether we have partial success.
        /// </summary>
        public bool PartialSuccess
        {
            get { return this.partialSuccess; }
        }
    }
}
