// <copyright file="PacketUserauthRequestNone.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketUserauthRequestNone
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketUserauthRequestNone packet.
    /// </summary>
    public class PacketUserauthRequestNone
    {
        private byte[] payload;

        private string userName;
        private string serviceName;

        /// <summary>
        /// Initializes a new instance of the PacketUserauthRequestNone class.
        /// </summary>
        /// <param name="serviceName">The service name to start after authentication.</param>
        /// <param name="user">The user name in UTF-8.</param>
        public PacketUserauthRequestNone(string serviceName, string user)
        {
            this.serviceName = serviceName;
            this.userName = user;
        }

        /// <summary>
        /// Initializes a new instance of the PacketUserauthRequestNone class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketUserauthRequestNone(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageUserAuthorizationRequest)
            {
                throw new IOException("This is not a SSHMessageUserAuthorizationREQUEST! (" + packet_type + ")");
            }

            this.userName = tr.ReadString();
            this.serviceName = tr.ReadString();

            string method = tr.ReadString();

            if (method.Equals("none") == false)
            {
                throw new IOException("This is not a SSHMessageUserAuthorizationREQUEST with type none!");
            }

            if (tr.Remain != 0)
            {
                throw new IOException("Padding in SSHMessageUserAuthorizationREQUEST packet!");
            }
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageUserAuthorizationRequest);
                    tw.WriteString(this.userName);
                    tw.WriteString(this.serviceName);
                    tw.WriteString("none");
                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
