// <copyright file="PacketUserauthRequestPublicKey.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketUserauthRequestPublicKey
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketUserauthRequestPublicKey packet.
    /// </summary>
    public class PacketUserauthRequestPublicKey
    {
        private byte[] payload;

        private string userName;
        private string serviceName;
        
        // private string password;
        private string algoName;
        private byte[] pk;
        private byte[] sig;

        /// <summary>
        /// Initializes a new instance of the PacketUserauthRequestPublicKey class.
        /// </summary>
        /// <param name="serviceName">The service name to start after authentication.</param>
        /// <param name="user">The user name in UTF-8.</param>
        /// <param name="algorithmName">The name of the public key algorithm.</param>
        /// <param name="publicKey">A byte array containing the public key.</param>
        /// <param name="signature">Signature by the private key over this data (see RFC 4252).</param>
        public PacketUserauthRequestPublicKey(
            string serviceName,
            string user,
            string algorithmName,
            byte[] publicKey,
            byte[] signature)
        {
            this.serviceName = serviceName;
            this.userName = user;
            this.algoName = algorithmName;
            this.pk = publicKey;
            this.sig = signature;
        }

        /// <summary>
        /// Initializes a new instance of the PacketUserauthRequestPublicKey class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketUserauthRequestPublicKey(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageUserAuthorizationRequest)
            {
                throw new IOException("This is not a SSHMessageUserAuthorizationREQUEST! ("
                                      + packet_type + ")");
            }

            throw new IOException("Not implemented!");
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageUserAuthorizationRequest);
                    tw.WriteString(this.userName);
                    tw.WriteString(this.serviceName);
                    tw.WriteString("publickey");
                    tw.WriteBoolean(true);
                    tw.WriteString(this.algoName);
                    tw.WriteString(this.pk, 0, this.pk.Length);
                    tw.WriteString(this.sig, 0, this.sig.Length);
                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
