﻿// <copyright file="SFTPv3FileHandle.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> SFTPv3FileHandle
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;

namespace Eunomia.SSH2
{
    /// <summary>
    /// Holds the data for a sftp file handle.
    /// </summary>
    public class SFTPv3FileHandle
    {
        private SFTPv3Client client;
        private byte[] fileHandle;
        private bool closed;
        
        /// <summary>
        /// Initializes a new instance of the SFTPv3FileHandle class.
        /// </summary>
        /// <param name="client">The SFTP client where this file handle waas created.</param>
        /// <param name="h">The handle (byte array) as received from the server.</param>
        internal SFTPv3FileHandle(SFTPv3Client client, byte[] h)
        {
            this.client = client;
            this.fileHandle = h;
            this.closed = false;
        }

        /// <summary>
        /// Gets the SFTPv3Client instance which created this handle.
        /// </summary>
        public SFTPv3Client Client
        {
            get { return this.client; }
        }

        /// <summary>
        /// Gets the file handle receied from the server.
        /// </summary>
        public byte[] FileHandle
        {
            get { return this.fileHandle; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this handle was closed with the
        /// <see cref="SFTPv3Client.CloseFile"></see> method.
        /// </summary>
        public bool Closed
        {
            get { return this.closed; }
            set { this.closed = value; }
        }
    }
}