﻿// <copyright file="AttrTextHints.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> AttrTextHints
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

namespace Eunomia.SSH2.SFTP
{
    /// <summary>
    /// Values for the 'text-hint' field in the SFTP ATTRS data type.
    /// </summary>
    [SuppressMessage("Microsoft.Performance", "CA1815:OverrideEqualsAndOperatorEqualsOnValueTypes",
                    Justification = "We will never compare or sort instances of this struct.")]
    public struct AttrTextHints
    {
        /// <summary>
        /// The server knows the file is a text file, and should be opened
        /// using the SSH_FXF_ACCESS_TEXT_MODE flag.
        /// </summary>
        public const int SSHFileTransferAttributeKnownText = 0x00;

        /// <summary>
        /// The server has applied a heuristic or other mechanism and
        /// believes that the file should be opened with the
        /// SSH_FXF_ACCESS_TEXT_MODE flag.
        /// </summary>
        public const int SSHFileTransferAttributeGuessedText = 0x01;

        /// <summary>
        /// The server knows the file has binary content.
        /// </summary>
        public const int SSHFileTransferAttributeBinary = 0x02;

        /// <summary>
        /// The server has applied a heuristic or other mechanism and
        /// believes has binary content, and should not be opened with the
        /// SSH_FXF_ACCESS_TEXT_MODE flag.
        /// </summary>
        public const int SSHFileTransferAttributeGuessedBinary = 0x03;
    }
}
