﻿// <copyright file="AttribPermissions.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> AttribPermissions
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

namespace Eunomia.SSH2.SFTP
{
    /// <summary>
    /// Permissions for the 'permissions' field in the SFTP ATTRS data type.
    /// </summary>
    /// <remarks>
    /// The 'permissions' field contains a bit mask specifying file permissions.
    /// These permissions correspond to the st_mode field of the stat structure
    /// defined by POSIX [IEEE.1003-1.1996].
    /// </remarks>
    [SuppressMessage("Microsoft.Performance", "CA1815:OverrideEqualsAndOperatorEqualsOnValueTypes",
                    Justification = "We will never compare or sort instances of this struct.")]
    public struct AttribPermissions
    {
        // Octal values!
        
        /// <summary> Read, User bit. </summary>
        public const int ReadUserBit = 0400;

        /// <summary> Write, User bit. </summary>
        public const int WriteUserBit = 0200;

        /// <summary> Execute/Search, User bit. </summary>
        public const int ExecuteSearchUserBit = 0100;

        /// <summary> Read, Group bit. </summary>
        public const int ReadGroupBit = 0040;

        /// <summary> Write, Group bit. </summary>
        public const int WriteGroupBit = 0020;

        /// <summary> Execute/Search, Group bit. </summary>
        public const int ExecuteSearchGroupBit = 0010;

        /// <summary> Read, Others bit. </summary>
        public const int ReadOthersBit = 0004;

        /// <summary> Write, Otehrs bit. </summary>
        public const int WriteOthersBit = 0002;

        /// <summary> Execute/Search, Others bit. </summary>
        public const int ExecuteSearchOthersBit = 0001;

        /// <summary> Set User ID on execute bit. </summary>
        public const int SetUserId = 04000;

        /// <summary> Set Group ID on execute bit. </summary>
        public const int SetGroupId = 02000;

        /// <summary> Restricted directory delete bit. </summary>
        public const int RestrictedDirectoryDeleteBit = 01000;
    }
}
