// <copyright file="DSASignature.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> DSASignature
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Signature
{
    /// <summary>
    /// DSASignature.  Stores information about a DSA signature.
    /// </summary>
    public class DSASignature
    {
        private BigInteger r;
        private BigInteger s;

        /// <summary>
        /// Initializes a new instance of the DSASignature class.
        /// </summary>
        /// <param name="r">The r parameter.</param>
        /// <param name="s">The s parameter.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "r", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "s", Justification = "Consistancy to ganymed project.")]
        public DSASignature(BigInteger r, BigInteger s)
        {
            this.r = r;
            this.s = s;
        }
        
        /// <summary>
        /// Gets the R parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "R", Justification = "Consistancy to ganymed project.")]
        public BigInteger R 
        {
            get { return this.r; }
        }
        
        /// <summary>
        /// Gets the S parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "S", Justification = "Consistancy to ganymed project.")]
        public BigInteger S 
        {
            get { return this.s; }
        }
    }
}
