﻿// <copyright file="KexState.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> KexState
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;
using Eunomia.SSH2.DH;
using Eunomia.SSH2.Packets;
using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Transport
{
    /// <summary>
    /// Class used to store key exchange data and status.
    /// </summary>
    public class KexState
    {
        private PacketKexInit localKEX;
        private PacketKexInit remoteKEX;
        private NegotiatedParameters np;

        private int state = 0;

        private BigInteger k;
        private byte[] h;
        private byte[] hostkey;
        
        private DHExchange dhx;
        private DHGroupExchange dhgx;
        private DHGexParameters dhgexParameters;
        
        /// <summary>
        /// Gets or sets the local packet generated during key exchange.
        /// </summary>
        public PacketKexInit LocalKEX
        {
            get { return this.localKEX; }
            set { this.localKEX = value; }
        }
        
        /// <summary>
        /// Gets or sets the remote packet received during key exchange.
        /// </summary>
        public PacketKexInit RemoteKEX
        {
            get { return this.remoteKEX; }
            set { this.remoteKEX = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated parameters.
        /// </summary>
        public NegotiatedParameters NP
        {
            get { return this.np; }
            set { this.np = value; }
        }
        
        /// <summary>
        /// Gets or sets the state.
        /// Used in KexManager to track what step in the key exchange we have reached.
        /// </summary>
        public int State
        {
            get { return this.state; }
            set { this.state = value; }
        }

        /// <summary>
        /// Gets or sets the Diffie-Hellman shared secret.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "K", Justification = "Consistancy to ganymed project.")]
        public BigInteger K
        {
            get { return this.k; }
            set { this.k = value; }
        }
        
        /// <summary>
        /// Gets or sets the hash used to verify the DH data.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "H", Justification = "Consistancy to ganymed project.")]
        public byte[] H
        {
            get { return this.h; }
            set { this.h = value; }
        }
        
        /// <summary>
        /// Gets or sets the host key.
        /// </summary>
        public byte[] Hostkey
        {
            get { return this.hostkey; }
            set { this.hostkey = value; }
        }
        
        /// <summary>
        /// Gets or sets the DhExchange (old style DH) used during the key exchange.
        /// </summary>
        public DHExchange DHX
        {
            get { return this.dhx; }
            set { this.dhx = value; }
        }
        
        /// <summary>
        /// Gets or sets the DhGroupExchange (new style DH) used during the key exchange.
        /// </summary>
        public DHGroupExchange DHGX
        {
            get { return this.dhgx; }
            set { this.dhgx = value; }
        }
        
        /// <summary>
        /// Gets or sets the DHGexParameters used.
        /// </summary>
        public DHGexParameters DHGexParameters
        {
            get { return this.dhgexParameters; }
            set { this.dhgexParameters = value; }
        }
    }
}
