﻿// <copyright file="StringEncoder.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> StringEncoder
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Text;

namespace Eunomia.SSH2.Util
{
    /// <summary>
    /// Class to encode and encode strings using the iso-8859-1 character set.
    /// </summary>
    public static class StringEncoder
    {
        /// <summary>
        /// Converts a string to a byte array.
        /// </summary>
        /// <param name="data">The string to convert.</param>
        /// <returns>The coverted data in a byte array.</returns>
        public static byte[] GetBytes(string data)
        {
            try
            {
                return Encoding.GetEncoding("iso-8859-1").GetBytes(data);
            }
            catch (NotSupportedException)
            {
                byte[] bytes = new byte[data.Length];

                for (int i = 0; i < data.Length; i++)
                {
                    char c = data[i];
                    if (c > 127)
                    {
                        bytes[i] = 0x3F; // ?
                    }
                    else
                    {
                        bytes[i] = (byte)c;
                    }
                }

                return bytes;
            }
        }

        /// <summary>
        /// Convert a byte array into a string.
        /// </summary>
        /// <param name="data">A byte array to convert into a string.</param>
        /// <returns>The converted data as a string.</returns>
        public static string GetString(byte[] data)
        {
            return GetString(data, 0, data.Length);
        }
        
        /// <summary>
        /// Convert a byte array into a string.
        /// </summary>
        /// <param name="data">A byte array to convert into a string.</param>
        /// <param name="off">The strating offset into the byte array where we begin converting.</param>
        /// <param name="len">The number of bytes to convert.</param>
        /// <returns>The converted data as a string.</returns>
        public static string GetString(byte[] data, int off, int len)
        {
            try
            {
                return Encoding.GetEncoding("iso-8859-1").GetString(data, off, len);
            }
            catch (NotSupportedException)
            {
                char[] chars = new char[len];

                for (int i = 0; i < len; i++)
                {
                    char c = (char)data[off + i];
                    if (c > 127)
                    {
                        c = '?';
                    }
                    
                    chars[i] = c;
                }

                return new string(chars);
            }
        }
    }
}
