﻿// <copyright file="TimeoutToken.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> TimeoutToken
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.5.0, 12/17/2010
// </version>

using System;
using System.Collections;
using System.Threading;

using Eunomia.SSH2.Log;

namespace Eunomia.SSH2.Util
{
    /// <summary>
    /// Stores the duration and handler for a Timeout.
    /// </summary>
    public class TimeoutToken
    {
        private long runtime;
        private IThreadRunnable handler;

        /// <summary>
        /// Initializes a new instance of the TimeoutToken class.
        /// </summary>
        /// <param name="runtime">Timeout duration in milliseconds.</param>
        /// <param name="handler">Handler routine.</param>
        public TimeoutToken(long runtime, IThreadRunnable handler)
        {
            this.runtime = runtime;
            this.handler = handler;
        }
        
        /// <summary>
        /// Gets or sets a Handler routine for this timeout token.
        /// </summary>
        public IThreadRunnable Handler
        {
            get { return this.handler; }
            set { this.handler = value; }
        }
        
        /// <summary>
        /// Gets or sets a duration in milliseconds for ths timeout token.
        /// </summary>
        public long Runtime
        {
            get { return this.runtime; }
            set { this.runtime = value; }
        }
    }
}